class ConfigHelpers {
//
// some helper functions to assist in managing the widget configuration
//
// Call this function to fetch the current values of the configuration.  You supply a callback with a
// single parameter, which will be an Object with the key/value pairs already parsed out of the XML.
//
// The website will provide the value for "_chumby_instance_url", which is where you GET and POST the
// values, when the configuration movie is launched.
//
// In the hash, the keys and values should be either strings or numbers - you cannot stored complex objects directly.
// If you're adventurous, you *could* convert some structures to/from JSON or even XML and store them as text.
//
/* getWidgetParameters kicks off the load of the XML.  Note that there really isn't anything
*  available on return from there.  We just issue the request to the server and return.
*  When the callback function is called, then the data is available.
*/
function getWidgetParameters(callback:Function) {
	var XMLStartAt:Function = XMLStartAt;
	var chumby_xml:XML = new XML();
	chumby_xml.ignoreWhite = true;
	//Flash will call this after the XML arrives at the Chumby...
	chumby_xml.onLoad = function(success:Boolean) {
		var p:Object = {};
		if (success) {
			var aNode:XMLNode = XMLStartAt(this,'widget_instance');
			aNode=XMLStartAt(aNode,'widget_parameters');
			while (aNode=XMLStartAt(aNode,'widget_parameter')) {
				var nNode:XMLNode = XMLStartAt(aNode,'name').firstChild;
				var vNode:XMLNode = XMLStartAt(aNode,'value').firstChild;
				p[nNode.nodeValue]=vNode.nodeValue;
			}
		} else {
			p['error']='XML load failed';
		}
		callback(p);
	}
	//This actually starts the process...
	//chumby_xml.load('http://www.vrtisworks.com/testchumby.xml');
	chumby_xml.load(_root._chumby_instance_url);
}
// Find the start (first child) from XMLNode named by 'thename'
function XMLStartAt(thexml:XMLNode,thename:String):XMLNode {
	var aNode:XMLNode = thexml.firstChild;	//Start looking from here..
	while (aNode) {
		//Check to see if this is the one we want...
		trace ('aNode:'+aNode.nodeName);
		if (aNode.nodeName==thename) {
			return aNode;
		}
		aNode=aNode.nextSibling;	//That wasn't it.. try the next child...
	}
	return null;	//Went through the whole list and couldn't find it...
}
function setWidgetParameters(callback:Function,parms:Object) {
	var XMLStartAt:Function = XMLStartAt;
	var chumby_xml:XML = new XML();
	chumby_xml.onLoad = undefined;
	var widget_parameters_xml:XMLNode = chumby_xml.createElement('widget_parameters');
	for (var pname in parms) {
		var widget_parameter_xml:XMLNode = chumby_xml.createElement('widget_parameter');
		var name_xml:XMLNode = chumby_xml.createElement('name');
		name_xml.appendChild(chumby_xml.createTextNode(pname));
		var value_xml:XMLNode = chumby_xml.createElement('value');
		value_xml.appendChild(chumby_xml.createTextNode(parms[pname]));
		widget_parameter_xml.appendChild(name_xml);
		widget_parameter_xml.appendChild(value_xml);
		widget_parameters_xml.appendChild(widget_parameter_xml);
	}
	var widget_instance_xml:XMLNode = chumby_xml.createElement('widget_instance');
	widget_instance_xml.appendChild(widget_parameters_xml);
	chumby_xml.appendChild(widget_instance_xml);
	var chumby_result_xml:XML = new XML();
	chumby_result_xml.onLoad = function(success:Boolean) {
		var p:Object = {};
		if (success) {
			p['result']='XML reloaded';
		} else {
			p['error']='XML reload failed';
		}
		callback(p);
    }
	chumby_xml.sendAndLoad(_root._chumby_instance_url,chumby_result_xml);
}
	//
	// Call this function to dismiss the dialog - it tells the hosting webpage to remove the movie from the page
	//
	function chumbyExit() {
		getURL('javascript:dismiss()');
	}
	//
	// called as a callback when done saving the data to the server
	//
	function doQuit() {
		chumbyExit();
	}
}
